package java.awt;

import java.io.Serializable;

public class BorderLayout implements LayoutManager2, Serializable {
   int hgap;
   int vgap;
   Component north;
   Component west;
   Component east;
   Component south;
   Component center;
   public static final String NORTH = "North";
   public static final String SOUTH = "South";
   public static final String EAST = "East";
   public static final String WEST = "West";
   public static final String CENTER = "Center";
   private static final long serialVersionUID = -8658291919501921765L;

   public BorderLayout() {
      this(0, 0);
   }

   public BorderLayout(int var1, int var2) {
      this.hgap = var1;
      this.vgap = var2;
   }

   public int getHgap() {
      return this.hgap;
   }

   public void setHgap(int var1) {
      this.hgap = var1;
   }

   public int getVgap() {
      return this.vgap;
   }

   public void setVgap(int var1) {
      this.vgap = var1;
   }

   public void addLayoutComponent(Component var1, Object var2) {
      Object var3 = var1.getTreeLock();
      synchronized(var3){}

      try {
         if (var2 != null && !(var2 instanceof String)) {
            throw new IllegalArgumentException("cannot add to layout: constraint must be a string (or null)");
         }

         this.addLayoutComponent((String)var2, var1);
      } catch (Throwable var5) {
         throw var5;
      }

   }

   /** @deprecated */
   public void addLayoutComponent(String var1, Component var2) {
      Object var3 = var2.getTreeLock();
      synchronized(var3){}

      try {
         if (var1 == null) {
            var1 = "Center";
         }

         if ("Center".equals(var1)) {
            this.center = var2;
         } else if ("North".equals(var1)) {
            this.north = var2;
         } else if ("South".equals(var1)) {
            this.south = var2;
         } else if ("East".equals(var1)) {
            this.east = var2;
         } else {
            if (!"West".equals(var1)) {
               throw new IllegalArgumentException("cannot add to layout: unknown constraint: " + var1);
            }

            this.west = var2;
         }
      } catch (Throwable var5) {
         throw var5;
      }

   }

   public void removeLayoutComponent(Component var1) {
      Object var2 = var1.getTreeLock();
      synchronized(var2){}

      try {
         if (var1 == this.center) {
            this.center = null;
         } else if (var1 == this.north) {
            this.north = null;
         } else if (var1 == this.south) {
            this.south = null;
         } else if (var1 == this.east) {
            this.east = null;
         } else if (var1 == this.west) {
            this.west = null;
         }
      } catch (Throwable var4) {
         throw var4;
      }

   }

   public Dimension minimumLayoutSize(Container var1) {
      Object var3 = ((Component)var1).getTreeLock();
      synchronized(var3){}

      Dimension var2;
      try {
         Dimension var5 = new Dimension(0, 0);
         if (this.east != null && this.east.visible) {
            Dimension var6 = this.east.getMinimumSize();
            var5.width += var6.width + this.hgap;
            var5.height = Math.max(var6.height, var5.height);
         }

         if (this.west != null && this.west.visible) {
            Dimension var9 = this.west.getMinimumSize();
            var5.width += var9.width + this.hgap;
            var5.height = Math.max(var9.height, var5.height);
         }

         if (this.center != null && this.center.visible) {
            Dimension var10 = this.center.getMinimumSize();
            var5.width += var10.width;
            var5.height = Math.max(var10.height, var5.height);
         }

         if (this.north != null && this.north.visible) {
            Dimension var11 = this.north.getMinimumSize();
            var5.width = Math.max(var11.width, var5.width);
            var5.height += var11.height + this.vgap;
         }

         if (this.south != null && this.south.visible) {
            Dimension var12 = this.south.getMinimumSize();
            var5.width = Math.max(var12.width, var5.width);
            var5.height += var12.height + this.vgap;
         }

         Insets var13 = var1.getInsets();
         var5.width += var13.left + var13.right;
         var5.height += var13.top + var13.bottom;
         var2 = var5;
      } catch (Throwable var8) {
         throw var8;
      }

      return var2;
   }

   public Dimension preferredLayoutSize(Container var1) {
      Object var3 = ((Component)var1).getTreeLock();
      synchronized(var3){}

      Dimension var2;
      try {
         Dimension var5 = new Dimension(0, 0);
         if (this.east != null && this.east.visible) {
            Dimension var6 = this.east.getPreferredSize();
            var5.width += var6.width + this.hgap;
            var5.height = Math.max(var6.height, var5.height);
         }

         if (this.west != null && this.west.visible) {
            Dimension var9 = this.west.getPreferredSize();
            var5.width += var9.width + this.hgap;
            var5.height = Math.max(var9.height, var5.height);
         }

         if (this.center != null && this.center.visible) {
            Dimension var10 = this.center.getPreferredSize();
            var5.width += var10.width;
            var5.height = Math.max(var10.height, var5.height);
         }

         if (this.north != null && this.north.visible) {
            Dimension var11 = this.north.getPreferredSize();
            var5.width = Math.max(var11.width, var5.width);
            var5.height += var11.height + this.vgap;
         }

         if (this.south != null && this.south.visible) {
            Dimension var12 = this.south.getPreferredSize();
            var5.width = Math.max(var12.width, var5.width);
            var5.height += var12.height + this.vgap;
         }

         Insets var13 = var1.getInsets();
         var5.width += var13.left + var13.right;
         var5.height += var13.top + var13.bottom;
         var2 = var5;
      } catch (Throwable var8) {
         throw var8;
      }

      return var2;
   }

   public Dimension maximumLayoutSize(Container var1) {
      return new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE);
   }

   public float getLayoutAlignmentX(Container var1) {
      return 0.5F;
   }

   public float getLayoutAlignmentY(Container var1) {
      return 0.5F;
   }

   public void invalidateLayout(Container var1) {
   }

   public void layoutContainer(Container var1) {
      Object var2 = ((Component)var1).getTreeLock();
      synchronized(var2){}

      try {
         Insets var4 = var1.getInsets();
         int var5 = var4.top;
         int var6 = var1.height - var4.bottom;
         int var7 = var4.left;
         int var8 = var1.width - var4.right;
         if (this.north != null && this.north.visible) {
            this.north.setSize(var8 - var7, this.north.height);
            Dimension var9 = this.north.getPreferredSize();
            this.north.setBounds(var7, var5, var8 - var7, var9.height);
            var5 += var9.height + this.vgap;
         }

         if (this.south != null && this.south.visible) {
            this.south.setSize(var8 - var7, this.south.height);
            Dimension var12 = this.south.getPreferredSize();
            this.south.setBounds(var7, var6 - var12.height, var8 - var7, var12.height);
            var6 -= var12.height + this.vgap;
         }

         if (this.east != null && this.east.visible) {
            this.east.setSize(this.east.width, var6 - var5);
            Dimension var13 = this.east.getPreferredSize();
            this.east.setBounds(var8 - var13.width, var5, var13.width, var6 - var5);
            var8 -= var13.width + this.hgap;
         }

         if (this.west != null && this.west.visible) {
            this.west.setSize(this.west.width, var6 - var5);
            Dimension var14 = this.west.getPreferredSize();
            this.west.setBounds(var7, var5, var14.width, var6 - var5);
            var7 += var14.width + this.hgap;
         }

         if (this.center != null && this.center.visible) {
            this.center.setBounds(var7, var5, var8 - var7, var6 - var5);
         }
      } catch (Throwable var11) {
         throw var11;
      }

   }

   public String toString() {
      return this.getClass().getName() + "[hgap=" + this.hgap + ",vgap=" + this.vgap + "]";
   }
}
