package java.awt;

import java.io.Serializable;
import java.util.Enumeration;
import java.util.Hashtable;

public class CardLayout implements LayoutManager2, Serializable {
   Hashtable tab;
   int hgap;
   int vgap;

   public CardLayout() {
      this(0, 0);
   }

   public CardLayout(int var1, int var2) {
      this.tab = new Hashtable();
      this.hgap = var1;
      this.vgap = var2;
   }

   public int getHgap() {
      return this.hgap;
   }

   public void setHgap(int var1) {
      this.hgap = var1;
   }

   public int getVgap() {
      return this.vgap;
   }

   public void setVgap(int var1) {
      this.vgap = var1;
   }

   public void addLayoutComponent(Component var1, Object var2) {
      Object var3 = var1.getTreeLock();
      synchronized(var3){}

      try {
         if (!(var2 instanceof String)) {
            throw new IllegalArgumentException("cannot add to layout: constraint must be a string");
         }

         this.addLayoutComponent((String)var2, var1);
      } catch (Throwable var5) {
         throw var5;
      }

   }

   /** @deprecated */
   public void addLayoutComponent(String var1, Component var2) {
      Object var3 = var2.getTreeLock();
      synchronized(var3){}

      try {
         if (this.tab.size() > 0) {
            var2.hide();
         }

         this.tab.put(var1, var2);
      } catch (Throwable var5) {
         throw var5;
      }

   }

   public void removeLayoutComponent(Component var1) {
      Object var2 = var1.getTreeLock();
      synchronized(var2){}

      try {
         Enumeration var4 = this.tab.keys();

         String var5;
         do {
            if (!var4.hasMoreElements()) {
               return;
            }

            var5 = (String)var4.nextElement();
         } while(this.tab.get(var5) != var1);

         this.tab.remove(var5);
      } catch (Throwable var7) {
         throw var7;
      }

   }

   public Dimension preferredLayoutSize(Container var1) {
      Object var3 = ((Component)var1).getTreeLock();
      synchronized(var3){}

      Dimension var2;
      try {
         Insets var5 = var1.getInsets();
         int var6 = var1.getComponentCount();
         int var7 = 0;
         int var8 = 0;

         for(int var9 = 0; var9 < var6; ++var9) {
            Component var10 = var1.getComponent(var9);
            Dimension var11 = var10.getPreferredSize();
            if (var11.width > var7) {
               var7 = var11.width;
            }

            if (var11.height > var8) {
               var8 = var11.height;
            }
         }

         var2 = new Dimension(var5.left + var5.right + var7 + this.hgap * 2, var5.top + var5.bottom + var8 + this.vgap * 2);
      } catch (Throwable var13) {
         throw var13;
      }

      return var2;
   }

   public Dimension minimumLayoutSize(Container var1) {
      Object var3 = ((Component)var1).getTreeLock();
      synchronized(var3){}

      Dimension var2;
      try {
         Insets var5 = var1.getInsets();
         int var6 = var1.getComponentCount();
         int var7 = 0;
         int var8 = 0;

         for(int var9 = 0; var9 < var6; ++var9) {
            Component var10 = var1.getComponent(var9);
            Dimension var11 = var10.getMinimumSize();
            if (var11.width > var7) {
               var7 = var11.width;
            }

            if (var11.height > var8) {
               var8 = var11.height;
            }
         }

         var2 = new Dimension(var5.left + var5.right + var7 + this.hgap * 2, var5.top + var5.bottom + var8 + this.vgap * 2);
      } catch (Throwable var13) {
         throw var13;
      }

      return var2;
   }

   public Dimension maximumLayoutSize(Container var1) {
      return new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE);
   }

   public float getLayoutAlignmentX(Container var1) {
      return 0.5F;
   }

   public float getLayoutAlignmentY(Container var1) {
      return 0.5F;
   }

   public void invalidateLayout(Container var1) {
   }

   public void layoutContainer(Container var1) {
      Object var2 = ((Component)var1).getTreeLock();
      synchronized(var2){}

      try {
         Insets var4 = var1.getInsets();
         int var5 = var1.getComponentCount();

         for(int var6 = 0; var6 < var5; ++var6) {
            Component var7 = var1.getComponent(var6);
            if (var7.visible) {
               var7.setBounds(this.hgap + var4.left, this.vgap + var4.top, var1.width - (this.hgap * 2 + var4.left + var4.right), var1.height - (this.vgap * 2 + var4.top + var4.bottom));
            }
         }
      } catch (Throwable var9) {
         throw var9;
      }

   }

   void checkLayout(Container var1) {
      if (var1.getLayout() != this) {
         throw new IllegalArgumentException("wrong parent for CardLayout");
      }
   }

   public void first(Container var1) {
      Object var2 = ((Component)var1).getTreeLock();
      synchronized(var2){}

      try {
         this.checkLayout(var1);
         int var4 = var1.getComponentCount();

         for(int var5 = 0; var5 < var4; ++var5) {
            Component var6 = var1.getComponent(var5);
            if (var6.visible) {
               var6.hide();
               var6 = var1.getComponent(0);
               var6.show();
               var1.validate();
               return;
            }
         }

      } catch (Throwable var8) {
         throw var8;
      }
   }

   public void next(Container var1) {
      Object var2 = ((Component)var1).getTreeLock();
      synchronized(var2){}

      try {
         this.checkLayout(var1);
         int var4 = var1.getComponentCount();

         for(int var5 = 0; var5 < var4; ++var5) {
            Component var6 = var1.getComponent(var5);
            if (var6.visible) {
               var6.hide();
               var6 = var1.getComponent(var5 + 1 < var4 ? var5 + 1 : 0);
               var6.show();
               var1.validate();
               return;
            }
         }

      } catch (Throwable var8) {
         throw var8;
      }
   }

   public void previous(Container var1) {
      Object var2 = ((Component)var1).getTreeLock();
      synchronized(var2){}

      try {
         this.checkLayout(var1);
         int var4 = var1.getComponentCount();

         for(int var5 = 0; var5 < var4; ++var5) {
            Component var6 = var1.getComponent(var5);
            if (var6.visible) {
               var6.hide();
               var6 = var1.getComponent(var5 > 0 ? var5 - 1 : var4 - 1);
               var6.show();
               var1.validate();
               return;
            }
         }

      } catch (Throwable var8) {
         throw var8;
      }
   }

   public void last(Container var1) {
      Object var2 = ((Component)var1).getTreeLock();
      synchronized(var2){}

      try {
         this.checkLayout(var1);
         int var4 = var1.getComponentCount();

         for(int var5 = 0; var5 < var4; ++var5) {
            Component var6 = var1.getComponent(var5);
            if (var6.visible) {
               var6.hide();
               var6 = var1.getComponent(var4 - 1);
               var6.show();
               var1.validate();
               return;
            }
         }

      } catch (Throwable var8) {
         throw var8;
      }
   }

   public void show(Container var1, String var2) {
      Object var3 = ((Component)var1).getTreeLock();
      synchronized(var3){}

      try {
         this.checkLayout(var1);
         Component var5 = (Component)this.tab.get(var2);
         if (var5 != null && !var5.visible) {
            int var6 = var1.getComponentCount();

            for(int var7 = 0; var7 < var6; ++var7) {
               Component var8 = var1.getComponent(var7);
               if (var8.visible) {
                  var8.hide();
                  break;
               }
            }

            var5.show();
            var1.validate();
         }
      } catch (Throwable var10) {
         throw var10;
      }

   }

   public String toString() {
      return this.getClass().getName() + "[hgap=" + this.hgap + ",vgap=" + this.vgap + "]";
   }
}
