package java.awt;

import java.awt.event.ComponentEvent;
import java.awt.event.ComponentListener;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;
import java.awt.event.PaintEvent;
import java.awt.event.WindowEvent;
import java.awt.image.ColorModel;
import java.awt.image.ImageObserver;
import java.awt.image.ImageProducer;
import java.awt.peer.ComponentPeer;
import java.awt.peer.LightweightPeer;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.PrintStream;
import java.io.PrintWriter;
import java.io.Serializable;
import java.util.EventObject;
import java.util.Locale;
import java.util.Vector;
import sun.awt.im.InputContext;

public abstract class Component implements ImageObserver, MenuContainer, Serializable {
   transient ComponentPeer peer;
   transient Container parent;
   // $FF: renamed from: x int
   int field_0;
   // $FF: renamed from: y int
   int field_1;
   int width;
   int height;
   Color foreground;
   Color background;
   Font font;
   Cursor cursor = Cursor.getPredefinedCursor(0);
   Locale locale;
   boolean visible = true;
   boolean enabled = true;
   boolean valid = false;
   Vector popups;
   String name;
   static final Object LOCK = new Object();
   Dimension minSize;
   Dimension prefSize;
   boolean newEventsOnly = false;
   transient ComponentListener componentListener;
   transient FocusListener focusListener;
   transient KeyListener keyListener;
   transient MouseListener mouseListener;
   transient MouseMotionListener mouseMotionListener;
   static final String actionListenerK = "actionL";
   static final String adjustmentListenerK = "adjustmentL";
   static final String componentListenerK = "componentL";
   static final String containerListenerK = "containerL";
   static final String focusListenerK = "focusL";
   static final String itemListenerK = "itemL";
   static final String keyListenerK = "keyL";
   static final String mouseListenerK = "mouseL";
   static final String mouseMotionListenerK = "mouseMotionL";
   static final String textListenerK = "textL";
   static final String windowListenerK = "windowL";
   long eventMask;
   static boolean isInc;
   static int incRate;
   public static final float TOP_ALIGNMENT = 0.0F;
   public static final float CENTER_ALIGNMENT = 0.5F;
   public static final float BOTTOM_ALIGNMENT = 1.0F;
   public static final float LEFT_ALIGNMENT = 0.0F;
   public static final float RIGHT_ALIGNMENT = 1.0F;
   private static final long serialVersionUID = -7644114512714619750L;
   private int componentSerializedDataVersion = 1;

   protected Component() {
   }

   public String getName() {
      return this.name;
   }

   public void setName(String var1) {
      this.name = var1;
   }

   public Container getParent() {
      return this.parent;
   }

   /** @deprecated */
   public ComponentPeer getPeer() {
      return this.peer;
   }

   public final Object getTreeLock() {
      return LOCK;
   }

   public Toolkit getToolkit() {
      ComponentPeer var1 = this.peer;
      if (var1 != null && !(var1 instanceof LightweightPeer)) {
         return var1.getToolkit();
      } else {
         Container var2 = this.parent;
         return var2 != null ? ((Component)var2).getToolkit() : Toolkit.getDefaultToolkit();
      }
   }

   public boolean isValid() {
      return this.peer != null && this.valid;
   }

   public boolean isVisible() {
      return this.visible;
   }

   public boolean isShowing() {
      if (this.visible && this.peer != null) {
         Container var1 = this.parent;
         return var1 == null || ((Component)var1).isShowing();
      } else {
         return false;
      }
   }

   public boolean isEnabled() {
      return this.enabled;
   }

   public void setEnabled(boolean var1) {
      this.enable(var1);
   }

   /** @deprecated */
   public void enable() {
      if (!this.enabled) {
         this.enabled = true;
         ComponentPeer var1 = this.peer;
         if (var1 != null) {
            var1.enable();
         }
      }

   }

   /** @deprecated */
   public void enable(boolean var1) {
      if (var1) {
         this.enable();
      } else {
         this.disable();
      }
   }

   /** @deprecated */
   public void disable() {
      if (this.enabled) {
         this.enabled = false;
         ComponentPeer var1 = this.peer;
         if (var1 != null) {
            var1.disable();
         }
      }

   }

   public void setVisible(boolean var1) {
      this.show(var1);
   }

   /** @deprecated */
   public void show() {
      if (!this.visible) {
         this.visible = true;
         ComponentPeer var1 = this.peer;
         if (var1 != null) {
            var1.show();
            if (var1 instanceof LightweightPeer) {
               this.repaint();
            }
         }

         if (this.componentListener != null || (this.eventMask & 1L) != 0L) {
            ComponentEvent var2 = new ComponentEvent(this, 102);
            Toolkit.getEventQueue().postEvent(var2);
         }

         Container var3 = this.parent;
         if (var3 != null) {
            var3.invalidate();
         }
      }

   }

   /** @deprecated */
   public void show(boolean var1) {
      if (var1) {
         this.show();
      } else {
         this.hide();
      }
   }

   /** @deprecated */
   public void hide() {
      if (this.visible) {
         Object var1 = this.getTreeLock();
         synchronized(var1){}

         try {
            this.visible = false;
            ComponentPeer var3 = this.peer;
            if (var3 != null) {
               var3.hide();
               if (var3 instanceof LightweightPeer) {
                  this.repaint();
               }
            }

            if (this.componentListener != null || (this.eventMask & 1L) != 0L) {
               ComponentEvent var4 = new ComponentEvent(this, 103);
               Toolkit.getEventQueue().postEvent(var4);
            }

            Container var7 = this.parent;
            if (var7 != null) {
               var7.invalidate();
            }
         } catch (Throwable var6) {
            throw var6;
         }

      }
   }

   public Color getForeground() {
      Color var1 = this.foreground;
      if (var1 != null) {
         return var1;
      } else {
         Container var2 = this.parent;
         return var2 != null ? ((Component)var2).getForeground() : null;
      }
   }

   public void setForeground(Color var1) {
      ComponentPeer var2 = this.peer;
      this.foreground = var1;
      if (var2 != null) {
         var1 = this.getForeground();
         if (var1 != null) {
            var2.setForeground(var1);
         }
      }

   }

   public Color getBackground() {
      Color var1 = this.background;
      if (var1 != null) {
         return var1;
      } else {
         Container var2 = this.parent;
         return var2 != null ? ((Component)var2).getBackground() : null;
      }
   }

   public void setBackground(Color var1) {
      ComponentPeer var2 = this.peer;
      this.background = var1;
      if (var2 != null) {
         var1 = this.getBackground();
         if (var1 != null) {
            var2.setBackground(var1);
         }
      }

   }

   public Font getFont() {
      Font var1 = this.font;
      if (var1 != null) {
         return var1;
      } else {
         Container var2 = this.parent;
         return var2 != null ? ((Component)var2).getFont() : null;
      }
   }

   public void setFont(Font var1) {
      Object var2 = this.getTreeLock();
      synchronized(var2){}

      try {
         ComponentPeer var4 = this.peer;
         this.font = var1;
         if (var4 != null) {
            var1 = this.getFont();
            if (var1 != null) {
               var4.setFont(var1);
            }
         }
      } catch (Throwable var6) {
         throw var6;
      }

   }

   public Locale getLocale() {
      Locale var1 = this.locale;
      if (var1 != null) {
         return var1;
      } else {
         Container var2 = this.parent;
         if (var2 == null) {
            throw new IllegalComponentStateException("This component must have a parent in order to determine its locale");
         } else {
            return ((Component)var2).getLocale();
         }
      }
   }

   public void setLocale(Locale var1) {
      this.locale = var1;
   }

   public ColorModel getColorModel() {
      ComponentPeer var1 = this.peer;
      return var1 != null && !(var1 instanceof LightweightPeer) ? var1.getColorModel() : this.getToolkit().getColorModel();
   }

   public Point getLocation() {
      return this.location();
   }

   public Point getLocationOnScreen() {
      Object var2 = this.getTreeLock();
      synchronized(var2){}

      Point var1;
      try {
         if (this.peer == null || !this.isShowing()) {
            throw new IllegalComponentStateException("component must be showing on the screen to determine its location");
         }

         if (!(this.peer instanceof LightweightPeer)) {
            Point var10 = this.peer.getLocationOnScreen();
            var1 = var10;
            return var1;
         }

         Container var4 = this.getNativeContainer();
         Point var5 = var4.peer.getLocationOnScreen();

         for(Object var6 = this; var6 != var4; var6 = ((Component)var6).getParent()) {
            var5.x += ((Component)var6).field_0;
            var5.y += ((Component)var6).field_1;
         }

         var1 = var5;
      } catch (Throwable var8) {
         throw var8;
      }

      return var1;
   }

   /** @deprecated */
   public Point location() {
      return new Point(this.field_0, this.field_1);
   }

   public void setLocation(int var1, int var2) {
      this.move(var1, var2);
   }

   /** @deprecated */
   public void move(int var1, int var2) {
      this.setBounds(var1, var2, this.width, this.height);
   }

   public void setLocation(Point var1) {
      this.setLocation(var1.x, var1.y);
   }

   public Dimension getSize() {
      return this.size();
   }

   /** @deprecated */
   public Dimension size() {
      return new Dimension(this.width, this.height);
   }

   public void setSize(int var1, int var2) {
      this.resize(var1, var2);
   }

   /** @deprecated */
   public void resize(int var1, int var2) {
      this.setBounds(this.field_0, this.field_1, var1, var2);
   }

   public void setSize(Dimension var1) {
      this.resize(var1);
   }

   /** @deprecated */
   public void resize(Dimension var1) {
      this.setSize(var1.width, var1.height);
   }

   public Rectangle getBounds() {
      return this.bounds();
   }

   /** @deprecated */
   public Rectangle bounds() {
      return new Rectangle(this.field_0, this.field_1, this.width, this.height);
   }

   public void setBounds(int var1, int var2, int var3, int var4) {
      this.reshape(var1, var2, var3, var4);
   }

   /** @deprecated */
   public void reshape(int var1, int var2, int var3, int var4) {
      Object var5 = this.getTreeLock();
      synchronized(var5){}

      try {
         boolean var7 = this.width != var3 || this.height != var4;
         boolean var8 = this.field_0 != var1 || this.field_1 != var2;
         if (var7 || var8) {
            boolean var9 = this.peer instanceof LightweightPeer;
            int var10 = this.field_0;
            int var11 = this.field_1;
            if (this.parent != null) {
               var10 += this.parent.field_0;
               var11 += this.parent.field_1;
            }

            int var12 = this.width;
            int var13 = this.height;
            this.field_0 = var1;
            this.field_1 = var2;
            this.width = var3;
            this.height = var4;
            if (this.peer != null) {
               if (var9) {
                  this.peer.setBounds(var1, var2, var3, var4);
               } else {
                  int var14 = var1;
                  int var15 = var2;

                  for(Container var16 = this.parent; var16 != null && var16.peer instanceof LightweightPeer; var16 = var16.parent) {
                     var14 += var16.field_0;
                     var15 += var16.field_1;
                  }

                  this.peer.setBounds(var14, var15, var3, var4);
               }

               if (var7) {
                  this.invalidate();
                  if (this.componentListener != null || (this.eventMask & 1L) != 0L) {
                     ComponentEvent var19 = new ComponentEvent(this, 101);
                     Toolkit.getEventQueue().postEvent(var19);
                  }
               }

               if (var8 && (this.componentListener != null || (this.eventMask & 1L) != 0L)) {
                  ComponentEvent var20 = new ComponentEvent(this, 100);
                  Toolkit.getEventQueue().postEvent(var20);
               }

               if (this.parent != null && this.parent.valid) {
                  this.parent.invalidate();
               }
            }

            if (var9 && this.isShowing()) {
               this.parent.repaint(var10, var11, var12, var13);
               this.repaint();
            }
         }
      } catch (Throwable var18) {
         throw var18;
      }

   }

   public void setBounds(Rectangle var1) {
      this.setBounds(var1.x, var1.y, var1.width, var1.height);
   }

   public Dimension getPreferredSize() {
      return this.preferredSize();
   }

   /** @deprecated */
   public Dimension preferredSize() {
      Dimension var1 = this.prefSize;
      if (var1 != null && this.isValid()) {
         return var1;
      } else {
         Object var3 = this.getTreeLock();
         synchronized(var3){}

         Dimension var2;
         try {
            this.prefSize = this.peer != null ? this.peer.preferredSize() : this.getMinimumSize();
            var2 = this.prefSize;
         } catch (Throwable var6) {
            throw var6;
         }

         return var2;
      }
   }

   public Dimension getMinimumSize() {
      return this.minimumSize();
   }

   /** @deprecated */
   public Dimension minimumSize() {
      Dimension var1 = this.minSize;
      if (var1 != null && this.isValid()) {
         return var1;
      } else {
         Object var3 = this.getTreeLock();
         synchronized(var3){}

         Dimension var2;
         try {
            this.minSize = this.peer != null ? this.peer.minimumSize() : this.size();
            var2 = this.minSize;
         } catch (Throwable var6) {
            throw var6;
         }

         return var2;
      }
   }

   public Dimension getMaximumSize() {
      return new Dimension(32767, 32767);
   }

   public float getAlignmentX() {
      return 0.5F;
   }

   public float getAlignmentY() {
      return 0.5F;
   }

   public void doLayout() {
      this.layout();
   }

   /** @deprecated */
   public void layout() {
   }

   public void validate() {
      if (!this.valid) {
         Object var1 = this.getTreeLock();
         synchronized(var1){}

         try {
            this.valid = true;
         } catch (Throwable var3) {
            throw var3;
         }

      }
   }

   public void invalidate() {
      Object var1 = this.getTreeLock();
      synchronized(var1){}

      try {
         this.valid = false;
         this.prefSize = null;
         this.minSize = null;
         if (this.parent != null && this.parent.valid) {
            this.parent.invalidate();
         }
      } catch (Throwable var3) {
         throw var3;
      }

   }

   public Graphics getGraphics() {
      if (this.peer instanceof LightweightPeer) {
         Graphics var2 = this.parent.getGraphics();
         var2.translate(this.field_0, this.field_1);
         var2.setClip(0, 0, this.width, this.height);
         var2.setFont(this.getFont());
         return var2;
      } else {
         ComponentPeer var1 = this.peer;
         return var1 != null ? var1.getGraphics() : null;
      }
   }

   public FontMetrics getFontMetrics(Font var1) {
      ComponentPeer var2 = this.peer;
      return var2 != null && !(var2 instanceof LightweightPeer) ? var2.getFontMetrics(var1) : this.getToolkit().getFontMetrics(var1);
   }

   public synchronized void setCursor(Cursor var1) {
      this.cursor = var1;
      ComponentPeer var2 = this.peer;
      if (var2 != null) {
         var2.setCursor(var1);
      }

   }

   public Cursor getCursor() {
      return this.cursor;
   }

   public void paint(Graphics var1) {
   }

   public void update(Graphics var1) {
      if (!(this.peer instanceof LightweightPeer)) {
         var1.setColor(this.getBackground());
         var1.fillRect(0, 0, this.width, this.height);
         var1.setColor(this.getForeground());
      }

      this.paint(var1);
   }

   public void paintAll(Graphics var1) {
      ComponentPeer var2 = this.peer;
      if (this.visible && var2 != null) {
         this.validate();
         if (var2 instanceof LightweightPeer) {
            this.paint(var1);
            return;
         }

         var2.paint(var1);
      }

   }

   public void repaint() {
      this.repaint(0L, 0, 0, this.width, this.height);
   }

   public void repaint(long var1) {
      this.repaint(var1, 0, 0, this.width, this.height);
   }

   public void repaint(int var1, int var2, int var3, int var4) {
      this.repaint(0L, var1, var2, var3, var4);
   }

   public void repaint(long var1, int var3, int var4, int var5, int var6) {
      if (this.peer instanceof LightweightPeer) {
         int var11 = this.field_0 + (var3 < 0 ? 0 : var3);
         int var8 = this.field_1 + (var4 < 0 ? 0 : var4);
         int var9 = var5 > this.width ? this.width : var5;
         int var10 = var6 > this.height ? this.height : var6;
         this.parent.repaint(var1, var11, var8, var9, var10);
      } else {
         ComponentPeer var7 = this.peer;
         if (var7 != null && var5 > 0 && var6 > 0) {
            var7.repaint(var1, var3, var4, var5, var6);
         }

      }
   }

   public void print(Graphics var1) {
      this.paint(var1);
   }

   public void printAll(Graphics var1) {
      ComponentPeer var2 = this.peer;
      if (this.visible && var2 != null) {
         this.validate();
         var2.print(var1);
      }

   }

   public boolean imageUpdate(Image var1, int var2, int var3, int var4, int var5, int var6) {
      int var7 = -1;
      if ((var2 & 48) != 0) {
         var7 = 0;
      } else if ((var2 & 8) != 0 && isInc) {
         try {
            var7 = incRate;
            if (var7 < 0) {
               var7 = 0;
            }
         } catch (Exception var8) {
            var7 = 100;
         }
      }

      if (var7 >= 0) {
         this.repaint((long)var7, 0, 0, this.width, this.height);
      }

      return (var2 & 160) == 0;
   }

   public Image createImage(ImageProducer var1) {
      ComponentPeer var2 = this.peer;
      return var2 != null && !(var2 instanceof LightweightPeer) ? var2.createImage(var1) : this.getToolkit().createImage(var1);
   }

   public Image createImage(int var1, int var2) {
      ComponentPeer var3 = this.peer;
      if (var3 instanceof LightweightPeer) {
         return this.parent.createImage(var1, var2);
      } else {
         return var3 != null ? var3.createImage(var1, var2) : null;
      }
   }

   public boolean prepareImage(Image var1, ImageObserver var2) {
      return this.prepareImage(var1, -1, -1, var2);
   }

   public boolean prepareImage(Image var1, int var2, int var3, ImageObserver var4) {
      ComponentPeer var5 = this.peer;
      if (var5 instanceof LightweightPeer) {
         return this.parent.prepareImage(var1, var2, var3, var4);
      } else {
         return var5 != null ? var5.prepareImage(var1, var2, var3, var4) : this.getToolkit().prepareImage(var1, var2, var3, var4);
      }
   }

   public int checkImage(Image var1, ImageObserver var2) {
      return this.checkImage(var1, -1, -1, var2);
   }

   public int checkImage(Image var1, int var2, int var3, ImageObserver var4) {
      ComponentPeer var5 = this.peer;
      if (var5 instanceof LightweightPeer) {
         return this.parent.checkImage(var1, var2, var3, var4);
      } else {
         return var5 != null ? var5.checkImage(var1, var2, var3, var4) : this.getToolkit().checkImage(var1, var2, var3, var4);
      }
   }

   public boolean contains(int var1, int var2) {
      return this.inside(var1, var2);
   }

   /** @deprecated */
   public boolean inside(int var1, int var2) {
      return var1 >= 0 && var1 < this.width && var2 >= 0 && var2 < this.height;
   }

   public boolean contains(Point var1) {
      return this.contains(var1.x, var1.y);
   }

   public Component getComponentAt(int var1, int var2) {
      return this.locate(var1, var2);
   }

   /** @deprecated */
   public Component locate(int var1, int var2) {
      return this.contains(var1, var2) ? this : null;
   }

   public Component getComponentAt(Point var1) {
      return this.getComponentAt(var1.x, var1.y);
   }

   /** @deprecated */
   public void deliverEvent(Event var1) {
      this.postEvent(var1);
   }

   public final void dispatchEvent(AWTEvent var1) {
      this.dispatchEventImpl(var1);
   }

   void dispatchEventImpl(AWTEvent var1) {
      int var2 = var1.getID();
      if (this.areInputMethodsEnabled() && var1 instanceof ComponentEvent && !(var1 instanceof PaintEvent)) {
         InputContext var3 = this.getInputContext();
         if (var3 != null) {
            var3.dispatchEvent(var1);
            if (var1.isConsumed()) {
               return;
            }
         }
      }

      switch (var2) {
         case 401:
         case 402:
            Container var6 = (Container)(this instanceof Container ? this : this.parent);
            if (var6 != null) {
               var6.preProcessKeyEvent((KeyEvent)var1);
               if (var1.isConsumed()) {
                  return;
               }
            }
         case 501:
         default:
            break;
         case 1004:
            if (this.parent != null && !(this instanceof Window)) {
               this.parent.setFocusOwner(this);
            }

            this.ensureWindowActivation(var1);
            break;
         case 1005:
            this.ensureWindowActivation(var1);
      }

      if (this.newEventsOnly) {
         if (this.eventEnabled(var1)) {
            this.processEvent(var1);
         }
      } else if (!(var1 instanceof MouseEvent) || this.postsOldMouseEvents()) {
         Event var7 = var1.convertToOld();
         if (var7 != null) {
            int var4 = var7.key;
            int var5 = var7.modifiers;
            this.postEvent(var7);
            if (var7.isConsumed()) {
               var1.consume();
            }

            switch (var7.id) {
               case 401:
               case 402:
               case 403:
               case 404:
                  if (var7.key != var4) {
                     ((KeyEvent)var1).setKeyChar(var7.getKeyEventChar());
                  }

                  if (var7.modifiers != var5) {
                     ((KeyEvent)var1).setModifiers(var7.modifiers);
                  }
            }
         }
      }

      if (!var1.isConsumed() && var1 instanceof KeyEvent) {
         Container var8 = (Container)(this instanceof Container ? this : this.parent);
         if (var8 != null) {
            var8.postProcessKeyEvent((KeyEvent)var1);
         }
      }

      if (this.peer != null) {
         this.peer.handleEvent(var1);
      }

   }

   boolean areInputMethodsEnabled() {
      return (this.eventMask & 8L) != 0L || this.keyListener != null;
   }

   private void ensureWindowActivation(AWTEvent var1) {
      boolean var2 = false;
      switch (var1.getID()) {
         case 1004:
            var2 = true;
            break;
         case 1005:
            var2 = false;
            break;
         default:
            return;
      }

      Window var3 = this.getWindowForObject(((EventObject)var1).getSource());
      if (var3 != null) {
         boolean var4 = var3.isActive();
         if (var2 && !var4 || !var2 && var4) {
            WindowEvent var5 = null;
            if (var2) {
               var5 = new WindowEvent(var3, 205);
            } else {
               boolean var6 = true;
               AWTEvent var7 = Toolkit.getEventQueue().peekEvent(1004);
               if (var7 != null && this.getWindowForObject(((EventObject)var7).getSource()) == var3) {
                  var6 = false;
               }

               if (var6) {
                  var5 = new WindowEvent(var3, 206);
               }
            }

            if (var5 != null) {
               Toolkit.getEventQueue().postEventAtHead(var5);
            }
         }

      }
   }

   private Window getWindowForObject(Object var1) {
      if (var1 instanceof Component) {
         while(var1 != null) {
            if (var1 instanceof Window) {
               return (Window)var1;
            }

            var1 = ((Component)var1).getParent();
         }
      }

      return null;
   }

   boolean eventEnabled(AWTEvent var1) {
      switch (var1.id) {
         case 100:
         case 101:
         case 102:
         case 103:
            if ((this.eventMask & 1L) != 0L || this.componentListener != null) {
               return true;
            }
            break;
         case 400:
         case 401:
         case 402:
            if ((this.eventMask & 8L) != 0L || this.keyListener != null) {
               return true;
            }
            break;
         case 500:
         case 501:
         case 502:
         case 504:
         case 505:
            if ((this.eventMask & 16L) != 0L || this.mouseListener != null) {
               return true;
            }
            break;
         case 503:
         case 506:
            if ((this.eventMask & 32L) != 0L || this.mouseMotionListener != null) {
               return true;
            }
            break;
         case 1004:
         case 1005:
            if ((this.eventMask & 4L) != 0L || this.focusListener != null) {
               return true;
            }
      }

      if (var1.id > 1999) {
         return true;
      } else {
         return false;
      }
   }

   /** @deprecated */
   public boolean postEvent(Event var1) {
      if (this.handleEvent(var1)) {
         var1.consume();
         return true;
      } else {
         Container var2 = this.parent;
         int var3 = var1.x;
         int var4 = var1.y;
         if (var2 != null) {
            var1.translate(this.field_0, this.field_1);
            if (((Component)var2).postEvent(var1)) {
               var1.consume();
               return true;
            }

            var1.x = var3;
            var1.y = var4;
         }

         return false;
      }
   }

   public synchronized void addComponentListener(ComponentListener var1) {
      this.componentListener = AWTEventMulticaster.add(this.componentListener, var1);
      this.newEventsOnly = true;
   }

   public synchronized void removeComponentListener(ComponentListener var1) {
      this.componentListener = AWTEventMulticaster.remove(this.componentListener, var1);
   }

   public synchronized void addFocusListener(FocusListener var1) {
      this.focusListener = AWTEventMulticaster.add(this.focusListener, var1);
      this.newEventsOnly = true;
      if (this.peer instanceof LightweightPeer) {
         this.parent.proxyEnableEvents(4L);
      }

   }

   public synchronized void removeFocusListener(FocusListener var1) {
      this.focusListener = AWTEventMulticaster.remove(this.focusListener, var1);
   }

   public synchronized void addKeyListener(KeyListener var1) {
      this.keyListener = AWTEventMulticaster.add(this.keyListener, var1);
      this.newEventsOnly = true;
      if (this.peer instanceof LightweightPeer) {
         this.parent.proxyEnableEvents(8L);
      }

   }

   public synchronized void removeKeyListener(KeyListener var1) {
      this.keyListener = AWTEventMulticaster.remove(this.keyListener, var1);
   }

   public synchronized void addMouseListener(MouseListener var1) {
      this.mouseListener = AWTEventMulticaster.add(this.mouseListener, var1);
      this.newEventsOnly = true;
      if (this.peer instanceof LightweightPeer) {
         this.parent.proxyEnableEvents(16L);
      }

   }

   public synchronized void removeMouseListener(MouseListener var1) {
      this.mouseListener = AWTEventMulticaster.remove(this.mouseListener, var1);
   }

   public synchronized void addMouseMotionListener(MouseMotionListener var1) {
      this.mouseMotionListener = AWTEventMulticaster.add(this.mouseMotionListener, var1);
      this.newEventsOnly = true;
      if (this.peer instanceof LightweightPeer) {
         this.parent.proxyEnableEvents(32L);
      }

   }

   public synchronized void removeMouseMotionListener(MouseMotionListener var1) {
      this.mouseMotionListener = AWTEventMulticaster.remove(this.mouseMotionListener, var1);
   }

   InputContext getInputContext() {
      Container var1 = this.parent;
      return var1 == null ? null : ((Component)var1).getInputContext();
   }

   protected final void enableEvents(long var1) {
      this.eventMask |= var1;
      this.newEventsOnly = true;
      if (this.peer instanceof LightweightPeer) {
         this.parent.proxyEnableEvents(this.eventMask);
      }

   }

   protected final void disableEvents(long var1) {
      this.eventMask &= ~var1;
   }

   protected void processEvent(AWTEvent var1) {
      if (var1 instanceof FocusEvent) {
         this.processFocusEvent((FocusEvent)var1);
      } else {
         if (var1 instanceof MouseEvent) {
            switch (var1.getID()) {
               case 500:
               case 501:
               case 502:
               case 504:
               case 505:
                  this.processMouseEvent((MouseEvent)var1);
                  return;
               case 503:
               case 506:
                  this.processMouseMotionEvent((MouseEvent)var1);
                  return;
            }
         } else {
            if (var1 instanceof KeyEvent) {
               this.processKeyEvent((KeyEvent)var1);
               return;
            }

            if (var1 instanceof ComponentEvent) {
               this.processComponentEvent((ComponentEvent)var1);
            }
         }

      }
   }

   protected void processComponentEvent(ComponentEvent var1) {
      if (this.componentListener != null) {
         int var2 = ((AWTEvent)var1).getID();
         switch (var2) {
            case 100:
               this.componentListener.componentMoved(var1);
               return;
            case 101:
               this.componentListener.componentResized(var1);
               return;
            case 102:
               this.componentListener.componentShown(var1);
               return;
            case 103:
               this.componentListener.componentHidden(var1);
               return;
         }
      }

   }

   protected void processFocusEvent(FocusEvent var1) {
      if (this.focusListener != null) {
         int var2 = ((AWTEvent)var1).getID();
         switch (var2) {
            case 1004:
               this.focusListener.focusGained(var1);
               return;
            case 1005:
               this.focusListener.focusLost(var1);
               return;
         }
      }

   }

   protected void processKeyEvent(KeyEvent var1) {
      if (this.keyListener != null) {
         int var2 = ((AWTEvent)var1).getID();
         switch (var2) {
            case 400:
               this.keyListener.keyTyped(var1);
               return;
            case 401:
               this.keyListener.keyPressed(var1);
               return;
            case 402:
               this.keyListener.keyReleased(var1);
               return;
         }
      }

   }

   protected void processMouseEvent(MouseEvent var1) {
      if (this.mouseListener != null) {
         int var2 = ((AWTEvent)var1).getID();
         switch (var2) {
            case 500:
               this.mouseListener.mouseClicked(var1);
               return;
            case 501:
               this.mouseListener.mousePressed(var1);
               return;
            case 502:
               this.mouseListener.mouseReleased(var1);
               return;
            case 503:
            default:
               break;
            case 504:
               this.mouseListener.mouseEntered(var1);
               return;
            case 505:
               this.mouseListener.mouseExited(var1);
               return;
         }
      }

   }

   protected void processMouseMotionEvent(MouseEvent var1) {
      if (this.mouseMotionListener != null) {
         int var2 = ((AWTEvent)var1).getID();
         switch (var2) {
            case 503:
               this.mouseMotionListener.mouseMoved(var1);
               return;
            case 506:
               this.mouseMotionListener.mouseDragged(var1);
               return;
         }
      }

   }

   boolean postsOldMouseEvents() {
      return false;
   }

   /** @deprecated */
   public boolean handleEvent(Event var1) {
      switch (var1.id) {
         case 401:
         case 403:
            return this.keyDown(var1, var1.key);
         case 402:
         case 404:
            return this.keyUp(var1, var1.key);
         case 501:
            return this.mouseDown(var1, var1.x, var1.y);
         case 502:
            return this.mouseUp(var1, var1.x, var1.y);
         case 503:
            return this.mouseMove(var1, var1.x, var1.y);
         case 504:
            return this.mouseEnter(var1, var1.x, var1.y);
         case 505:
            return this.mouseExit(var1, var1.x, var1.y);
         case 506:
            return this.mouseDrag(var1, var1.x, var1.y);
         case 1001:
            return this.action(var1, var1.arg);
         case 1004:
            return this.gotFocus(var1, var1.arg);
         case 1005:
            return this.lostFocus(var1, var1.arg);
         default:
            return false;
      }
   }

   /** @deprecated */
   public boolean mouseDown(Event var1, int var2, int var3) {
      return false;
   }

   /** @deprecated */
   public boolean mouseDrag(Event var1, int var2, int var3) {
      return false;
   }

   /** @deprecated */
   public boolean mouseUp(Event var1, int var2, int var3) {
      return false;
   }

   /** @deprecated */
   public boolean mouseMove(Event var1, int var2, int var3) {
      return false;
   }

   /** @deprecated */
   public boolean mouseEnter(Event var1, int var2, int var3) {
      return false;
   }

   /** @deprecated */
   public boolean mouseExit(Event var1, int var2, int var3) {
      return false;
   }

   /** @deprecated */
   public boolean keyDown(Event var1, int var2) {
      return false;
   }

   /** @deprecated */
   public boolean keyUp(Event var1, int var2) {
      return false;
   }

   /** @deprecated */
   public boolean action(Event var1, Object var2) {
      return false;
   }

   public void addNotify() {
      Object var1 = this.getTreeLock();
      synchronized(var1){}

      try {
         if (this.peer != null) {
            if (this.parent != null && this.parent.peer instanceof LightweightPeer) {
               new NativeInLightFixer(this);
            }
         } else {
            this.peer = this.getToolkit().createComponent(this);
            long var3 = 0L;
            if (this.mouseListener != null || (this.eventMask & 16L) != 0L) {
               var3 |= 16L;
            }

            if (this.mouseMotionListener != null || (this.eventMask & 32L) != 0L) {
               var3 |= 32L;
            }

            if (this.focusListener != null || (this.eventMask & 4L) != 0L) {
               var3 |= 4L;
            }

            if (this.keyListener != null || (this.eventMask & 8L) != 0L) {
               var3 |= 8L;
            }

            if (var3 != 0L) {
               this.parent.proxyEnableEvents(var3);
            }
         }

         this.invalidate();
         int var8 = this.popups != null ? this.popups.size() : 0;

         for(int var4 = 0; var4 < var8; ++var4) {
            PopupMenu var5 = (PopupMenu)this.popups.elementAt(var4);
            var5.addNotify();
         }

         for(Container var9 = this.getParent(); var9 != null; var9 = ((Component)var9).getParent()) {
            if (var9 instanceof Window) {
               ((Window)var9).getWarningString();
               break;
            }
         }
      } catch (Throwable var7) {
         throw var7;
      }

   }

   public void removeNotify() {
      Object var1 = this.getTreeLock();
      synchronized(var1){}

      try {
         if (this.areInputMethodsEnabled()) {
            InputContext var3 = this.getInputContext();
            if (var3 != null) {
               ComponentEvent var4 = new ComponentEvent(this, 103);
               var3.dispatchEvent(var4);
            }
         }

         int var8 = this.popups != null ? this.popups.size() : 0;

         for(int var9 = 0; var9 < var8; ++var9) {
            PopupMenu var5 = (PopupMenu)this.popups.elementAt(var9);
            ((Menu)var5).removeNotify();
         }

         if (this.peer != null) {
            ComponentPeer var10 = this.peer;
            var10.hide();
            Toolkit.getEventQueue().removeSourceEvents(this);
            this.peer = null;
            var10.dispose();
         }
      } catch (Throwable var7) {
         throw var7;
      }

   }

   /** @deprecated */
   public boolean gotFocus(Event var1, Object var2) {
      return false;
   }

   /** @deprecated */
   public boolean lostFocus(Event var1, Object var2) {
      return false;
   }

   public boolean isFocusTraversable() {
      ComponentPeer var1 = this.peer;
      return var1 != null ? var1.isFocusTraversable() : false;
   }

   public void requestFocus() {
      ComponentPeer var1 = this.peer;
      if (var1 != null) {
         if (var1 instanceof LightweightPeer) {
            this.parent.proxyRequestFocus(this);
            return;
         }

         var1.requestFocus();
         Toolkit.getEventQueue().changeKeyEventFocus(this);
      }

   }

   public void transferFocus() {
      this.nextFocus();
   }

   /** @deprecated */
   public void nextFocus() {
      Container var1 = this.parent;
      if (var1 != null) {
         var1.transferFocus(this);
      }

   }

   public synchronized void add(PopupMenu var1) {
      if (var1.parent != null) {
         var1.parent.remove(var1);
      }

      if (this.popups == null) {
         this.popups = new Vector();
      }

      this.popups.addElement(var1);
      var1.parent = this;
      if (this.peer != null && var1.peer == null) {
         var1.addNotify();
      }

   }

   public synchronized void remove(MenuComponent var1) {
      int var2 = this.popups.indexOf(var1);
      if (var2 >= 0) {
         PopupMenu var3 = (PopupMenu)var1;
         if (var3.peer != null) {
            ((Menu)var3).removeNotify();
         }

         var3.parent = null;
         this.popups.removeElementAt(var2);
         if (this.popups.size() == 0) {
            this.popups = null;
         }
      }

   }

   protected String paramString() {
      String var1 = (this.name != null ? this.name : "") + "," + this.field_0 + "," + this.field_1 + "," + this.width + "x" + this.height;
      if (!this.valid) {
         var1 = var1 + ",invalid";
      }

      if (!this.visible) {
         var1 = var1 + ",hidden";
      }

      if (!this.enabled) {
         var1 = var1 + ",disabled";
      }

      return var1;
   }

   public String toString() {
      return this.getClass().getName() + "[" + this.paramString() + "]";
   }

   public void list() {
      this.list((PrintStream)System.out, 0);
   }

   public void list(PrintStream var1) {
      this.list((PrintStream)var1, 0);
   }

   public void list(PrintStream var1, int var2) {
      for(int var3 = 0; var3 < var2; ++var3) {
         var1.print("  ");
      }

      var1.println(this);
   }

   public void list(PrintWriter var1) {
      this.list((PrintWriter)var1, 0);
   }

   public void list(PrintWriter var1, int var2) {
      for(int var3 = 0; var3 < var2; ++var3) {
         var1.print("  ");
      }

      var1.println(this);
   }

   Container getNativeContainer() {
      Container var1;
      for(var1 = this.parent; var1 != null && var1.peer instanceof LightweightPeer; var1 = ((Component)var1).getParent()) {
      }

      return var1;
   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      AWTEventMulticaster.save(var1, "componentL", this.componentListener);
      AWTEventMulticaster.save(var1, "focusL", this.focusListener);
      AWTEventMulticaster.save(var1, "keyL", this.keyListener);
      AWTEventMulticaster.save(var1, "mouseL", this.mouseListener);
      AWTEventMulticaster.save(var1, "mouseMotionL", this.mouseMotionListener);
      var1.writeObject((Object)null);
   }

   private void readObject(ObjectInputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultReadObject();

      Object var2;
      while((var2 = var1.readObject()) != null) {
         String var3 = ((String)var2).intern();
         if (var3 == "componentL") {
            this.addComponentListener((ComponentListener)var1.readObject());
         } else if (var3 == "focusL") {
            this.addFocusListener((FocusListener)var1.readObject());
         } else if (var3 == "keyL") {
            this.addKeyListener((KeyListener)var1.readObject());
         } else if (var3 == "mouseL") {
            this.addMouseListener((MouseListener)var1.readObject());
         } else if (var3 == "mouseMotionL") {
            this.addMouseMotionListener((MouseMotionListener)var1.readObject());
         } else {
            var1.readObject();
         }
      }

      if (this.popups != null) {
         int var6 = this.popups.size();

         for(int var4 = 0; var4 < var6; ++var4) {
            PopupMenu var5 = (PopupMenu)this.popups.elementAt(var4);
            var5.parent = this;
         }
      }

   }

   static {
      String var0 = System.getProperty("awt.image.incrementaldraw");
      isInc = var0 == null || var0.equals("true");
      var0 = System.getProperty("awt.image.redrawrate");
      incRate = var0 != null ? Integer.parseInt(var0) : 100;
   }
}
