package java.awt;

import java.io.Serializable;

public class FlowLayout implements LayoutManager, Serializable {
   public static final int LEFT = 0;
   public static final int CENTER = 1;
   public static final int RIGHT = 2;
   int align;
   int hgap;
   int vgap;
   private static final long serialVersionUID = -7262534875583282631L;

   public FlowLayout() {
      this(1, 5, 5);
   }

   public FlowLayout(int var1) {
      this(var1, 5, 5);
   }

   public FlowLayout(int var1, int var2, int var3) {
      this.align = var1;
      this.hgap = var2;
      this.vgap = var3;
   }

   public int getAlignment() {
      return this.align;
   }

   public void setAlignment(int var1) {
      this.align = var1;
   }

   public int getHgap() {
      return this.hgap;
   }

   public void setHgap(int var1) {
      this.hgap = var1;
   }

   public int getVgap() {
      return this.vgap;
   }

   public void setVgap(int var1) {
      this.vgap = var1;
   }

   public void addLayoutComponent(String var1, Component var2) {
   }

   public void removeLayoutComponent(Component var1) {
   }

   public Dimension preferredLayoutSize(Container var1) {
      Object var3 = ((Component)var1).getTreeLock();
      synchronized(var3){}

      Dimension var2;
      try {
         Dimension var5 = new Dimension(0, 0);
         int var6 = var1.getComponentCount();

         for(int var7 = 0; var7 < var6; ++var7) {
            Component var8 = var1.getComponent(var7);
            if (var8.visible) {
               Dimension var9 = var8.getPreferredSize();
               var5.height = Math.max(var5.height, var9.height);
               if (var7 > 0) {
                  var5.width += this.hgap;
               }

               var5.width += var9.width;
            }
         }

         Insets var12 = var1.getInsets();
         var5.width += var12.left + var12.right + this.hgap * 2;
         var5.height += var12.top + var12.bottom + this.vgap * 2;
         var2 = var5;
      } catch (Throwable var11) {
         throw var11;
      }

      return var2;
   }

   public Dimension minimumLayoutSize(Container var1) {
      Object var3 = ((Component)var1).getTreeLock();
      synchronized(var3){}

      Dimension var2;
      try {
         Dimension var5 = new Dimension(0, 0);
         int var6 = var1.getComponentCount();

         for(int var7 = 0; var7 < var6; ++var7) {
            Component var8 = var1.getComponent(var7);
            if (var8.visible) {
               Dimension var9 = var8.getMinimumSize();
               var5.height = Math.max(var5.height, var9.height);
               if (var7 > 0) {
                  var5.width += this.hgap;
               }

               var5.width += var9.width;
            }
         }

         Insets var12 = var1.getInsets();
         var5.width += var12.left + var12.right + this.hgap * 2;
         var5.height += var12.top + var12.bottom + this.vgap * 2;
         var2 = var5;
      } catch (Throwable var11) {
         throw var11;
      }

      return var2;
   }

   private void moveComponents(Container var1, int var2, int var3, int var4, int var5, int var6, int var7) {
      Object var8 = ((Component)var1).getTreeLock();
      synchronized(var8){}

      try {
         switch (this.align) {
            case 0:
            default:
               break;
            case 1:
               var2 += var4 / 2;
               break;
            case 2:
               var2 += var4;
         }

         for(int var10 = var6; var10 < var7; ++var10) {
            Component var11 = var1.getComponent(var10);
            if (var11.visible) {
               var11.setLocation(var2, var3 + (var5 - var11.height) / 2);
               var2 += this.hgap + var11.width;
            }
         }
      } catch (Throwable var13) {
         throw var13;
      }

   }

   public void layoutContainer(Container var1) {
      Object var2 = ((Component)var1).getTreeLock();
      synchronized(var2){}

      try {
         Insets var4 = var1.getInsets();
         int var5 = var1.width - (var4.left + var4.right + this.hgap * 2);
         int var6 = var1.getComponentCount();
         int var7 = 0;
         int var8 = var4.top + this.vgap;
         int var9 = 0;
         int var10 = 0;

         for(int var11 = 0; var11 < var6; ++var11) {
            Component var12 = var1.getComponent(var11);
            if (var12.visible) {
               Dimension var13 = var12.getPreferredSize();
               var12.setSize(var13.width, var13.height);
               if (var7 != 0 && var7 + var13.width > var5) {
                  this.moveComponents(var1, var4.left + this.hgap, var8, var5 - var7, var9, var10, var11);
                  var7 = var13.width;
                  var8 += this.vgap + var9;
                  var9 = var13.height;
                  var10 = var11;
               } else {
                  if (var7 > 0) {
                     var7 += this.hgap;
                  }

                  var7 += var13.width;
                  var9 = Math.max(var9, var13.height);
               }
            }
         }

         this.moveComponents(var1, var4.left + this.hgap, var8, var5 - var7, var9, var10, var6);
      } catch (Throwable var15) {
         throw var15;
      }

   }

   public String toString() {
      String var1 = "";
      switch (this.align) {
         case 0:
            var1 = ",align=left";
            break;
         case 1:
            var1 = ",align=center";
            break;
         case 2:
            var1 = ",align=right";
      }

      return this.getClass().getName() + "[hgap=" + this.hgap + ",vgap=" + this.vgap + var1 + "]";
   }
}
