package java.awt;

import java.io.Serializable;
import java.util.Hashtable;

public class GridBagLayout implements LayoutManager2, Serializable {
   protected static final int MAXGRIDSIZE = 512;
   protected static final int MINSIZE = 1;
   protected static final int PREFERREDSIZE = 2;
   protected Hashtable comptable = new Hashtable();
   protected GridBagConstraints defaultConstraints = new GridBagConstraints();
   protected GridBagLayoutInfo layoutInfo;
   public int[] columnWidths;
   public int[] rowHeights;
   public double[] columnWeights;
   public double[] rowWeights;

   public void setConstraints(Component var1, GridBagConstraints var2) {
      this.comptable.put(var1, var2.clone());
   }

   public GridBagConstraints getConstraints(Component var1) {
      GridBagConstraints var2 = (GridBagConstraints)this.comptable.get(var1);
      if (var2 == null) {
         this.setConstraints(var1, this.defaultConstraints);
         var2 = (GridBagConstraints)this.comptable.get(var1);
      }

      return (GridBagConstraints)var2.clone();
   }

   protected GridBagConstraints lookupConstraints(Component var1) {
      GridBagConstraints var2 = (GridBagConstraints)this.comptable.get(var1);
      if (var2 == null) {
         this.setConstraints(var1, this.defaultConstraints);
         var2 = (GridBagConstraints)this.comptable.get(var1);
      }

      return var2;
   }

   public Point getLayoutOrigin() {
      Point var1 = new Point(0, 0);
      if (this.layoutInfo != null) {
         var1.x = this.layoutInfo.startx;
         var1.y = this.layoutInfo.starty;
      }

      return var1;
   }

   public int[][] getLayoutDimensions() {
      if (this.layoutInfo == null) {
         return new int[2][0];
      } else {
         int[][] var1 = new int[][]{new int[this.layoutInfo.width], new int[this.layoutInfo.height]};
         System.arraycopy(this.layoutInfo.minWidth, 0, var1[0], 0, this.layoutInfo.width);
         System.arraycopy(this.layoutInfo.minHeight, 0, var1[1], 0, this.layoutInfo.height);
         return var1;
      }
   }

   public double[][] getLayoutWeights() {
      if (this.layoutInfo == null) {
         return new double[2][0];
      } else {
         double[][] var1 = new double[][]{new double[this.layoutInfo.width], new double[this.layoutInfo.height]};
         System.arraycopy(this.layoutInfo.weightX, 0, var1[0], 0, this.layoutInfo.width);
         System.arraycopy(this.layoutInfo.weightY, 0, var1[1], 0, this.layoutInfo.height);
         return var1;
      }
   }

   public Point location(int var1, int var2) {
      Point var3 = new Point(0, 0);
      if (this.layoutInfo == null) {
         return var3;
      } else {
         int var5 = this.layoutInfo.startx;

         int var4;
         for(var4 = 0; var4 < this.layoutInfo.width; ++var4) {
            var5 += this.layoutInfo.minWidth[var4];
            if (var5 > var1) {
               break;
            }
         }

         var3.x = var4;
         var5 = this.layoutInfo.starty;

         for(var4 = 0; var4 < this.layoutInfo.height; ++var4) {
            var5 += this.layoutInfo.minHeight[var4];
            if (var5 > var2) {
               break;
            }
         }

         var3.y = var4;
         return var3;
      }
   }

   public void addLayoutComponent(String var1, Component var2) {
   }

   public void addLayoutComponent(Component var1, Object var2) {
      if (var2 instanceof GridBagConstraints) {
         this.setConstraints(var1, (GridBagConstraints)var2);
      } else if (!(var2 instanceof String) && var2 != null) {
         throw new IllegalArgumentException("cannot add to layout: constraint must be a GridBagConstraint");
      }
   }

   public void removeLayoutComponent(Component var1) {
   }

   public Dimension preferredLayoutSize(Container var1) {
      GridBagLayoutInfo var2 = this.GetLayoutInfo(var1, 2);
      return this.GetMinSize(var1, var2);
   }

   public Dimension minimumLayoutSize(Container var1) {
      GridBagLayoutInfo var2 = this.GetLayoutInfo(var1, 1);
      return this.GetMinSize(var1, var2);
   }

   public Dimension maximumLayoutSize(Container var1) {
      return new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE);
   }

   public float getLayoutAlignmentX(Container var1) {
      return 0.5F;
   }

   public float getLayoutAlignmentY(Container var1) {
      return 0.5F;
   }

   public void invalidateLayout(Container var1) {
   }

   public void layoutContainer(Container var1) {
      this.ArrangeGrid(var1);
   }

   public String toString() {
      return this.getClass().getName();
   }

   protected GridBagLayoutInfo GetLayoutInfo(Container var1, int var2) {
      Object var4 = ((Component)var1).getTreeLock();
      synchronized(var4){}

      GridBagLayoutInfo var3;
      try {
         GridBagLayoutInfo var6 = new GridBagLayoutInfo();
         Component[] var10 = var1.getComponents();
         var6.width = var6.height = 0;
         int var23 = -1;
         int var22 = -1;
         int[] var28 = new int[512];
         int[] var29 = new int[512];

         for(int var11 = 0; var11 < var10.length; ++var11) {
            Component var7 = var10[var11];
            if (var7.isVisible()) {
               GridBagConstraints var8 = this.lookupConstraints(var7);
               int var18 = var8.gridx;
               int var19 = var8.gridy;
               int var20 = var8.gridwidth;
               if (var20 <= 0) {
                  var20 = 1;
               }

               int var21 = var8.gridheight;
               if (var21 <= 0) {
                  var21 = 1;
               }

               if (var18 < 0 && var19 < 0) {
                  if (var22 >= 0) {
                     var19 = var22;
                  } else if (var23 >= 0) {
                     var18 = var23;
                  } else {
                     var19 = 0;
                  }
               }

               if (var18 < 0) {
                  int var14 = 0;

                  for(int var42 = var19; var42 < var19 + var21; ++var42) {
                     var14 = Math.max(var14, var28[var42]);
                  }

                  var18 = var14 - var18 - 1;
                  if (var18 < 0) {
                     var18 = 0;
                  }
               } else if (var19 < 0) {
                  int var15 = 0;

                  for(int var12 = var18; var12 < var18 + var20; ++var12) {
                     var15 = Math.max(var15, var29[var12]);
                  }

                  var19 = var15 - var19 - 1;
                  if (var19 < 0) {
                     var19 = 0;
                  }
               }

               int var61;
               for(var61 = var18 + var20; var6.width < var61; ++var6.width) {
               }

               int var65;
               for(var65 = var19 + var21; var6.height < var65; ++var6.height) {
               }

               for(int var43 = var18; var43 < var18 + var20; ++var43) {
                  var29[var43] = var65;
               }

               for(int var44 = var19; var44 < var19 + var21; ++var44) {
                  var28[var44] = var61;
               }

               Dimension var9;
               if (var2 == 2) {
                  var9 = var7.getPreferredSize();
               } else {
                  var9 = var7.getMinimumSize();
               }

               var8.minWidth = var9.width;
               var8.minHeight = var9.height;
               if (var8.gridheight == 0 && var8.gridwidth == 0) {
                  var23 = -1;
                  var22 = -1;
               }

               if (var8.gridheight == 0 && var22 < 0) {
                  var23 = var18 + var20;
               } else if (var8.gridwidth == 0 && var23 < 0) {
                  var22 = var19 + var21;
               }
            }
         }

         if (this.columnWidths != null && var6.width < this.columnWidths.length) {
            var6.width = this.columnWidths.length;
         }

         if (this.rowHeights != null && var6.height < this.rowHeights.length) {
            var6.height = this.rowHeights.length;
         }

         var23 = -1;
         var22 = -1;
         var28 = new int[512];
         var29 = new int[512];

         for(int var40 = 0; var40 < var10.length; ++var40) {
            Component var36 = var10[var40];
            if (var36.isVisible()) {
               GridBagConstraints var38 = this.lookupConstraints(var36);
               int var70 = var38.gridx;
               int var71 = var38.gridy;
               int var72 = var38.gridwidth;
               int var73 = var38.gridheight;
               if (var70 < 0 && var71 < 0) {
                  if (var22 >= 0) {
                     var71 = var22;
                  } else if (var23 >= 0) {
                     var70 = var23;
                  } else {
                     var71 = 0;
                  }
               }

               if (var70 < 0) {
                  if (var73 <= 0) {
                     var73 += var6.height - var71;
                     if (var73 < 1) {
                        var73 = 1;
                     }
                  }

                  int var62 = 0;

                  for(int var46 = var71; var46 < var71 + var73; ++var46) {
                     var62 = Math.max(var62, var28[var46]);
                  }

                  var70 = var62 - var70 - 1;
                  if (var70 < 0) {
                     var70 = 0;
                  }
               } else if (var71 < 0) {
                  if (var72 <= 0) {
                     var72 += var6.width - var70;
                     if (var72 < 1) {
                        var72 = 1;
                     }
                  }

                  int var66 = 0;

                  for(int var45 = var70; var45 < var70 + var72; ++var45) {
                     var66 = Math.max(var66, var29[var45]);
                  }

                  var71 = var66 - var71 - 1;
                  if (var71 < 0) {
                     var71 = 0;
                  }
               }

               if (var72 <= 0) {
                  var72 += var6.width - var70;
                  if (var72 < 1) {
                     var72 = 1;
                  }
               }

               if (var73 <= 0) {
                  var73 += var6.height - var71;
                  if (var73 < 1) {
                     var73 = 1;
                  }
               }

               int var63 = var70 + var72;
               int var67 = var71 + var73;

               for(int var47 = var70; var47 < var70 + var72; ++var47) {
                  var29[var47] = var67;
               }

               for(int var48 = var71; var48 < var71 + var73; ++var48) {
                  var28[var48] = var63;
               }

               if (var38.gridheight == 0 && var38.gridwidth == 0) {
                  var23 = -1;
                  var22 = -1;
               }

               if (var38.gridheight == 0 && var22 < 0) {
                  var23 = var70 + var72;
               } else if (var38.gridwidth == 0 && var23 < 0) {
                  var22 = var71 + var73;
               }

               var38.tempX = var70;
               var38.tempY = var71;
               var38.tempWidth = var72;
               var38.tempHeight = var73;
            }
         }

         if (this.columnWidths != null) {
            System.arraycopy(this.columnWidths, 0, var6.minWidth, 0, this.columnWidths.length);
         }

         if (this.rowHeights != null) {
            System.arraycopy(this.rowHeights, 0, var6.minHeight, 0, this.rowHeights.length);
         }

         if (this.columnWeights != null) {
            System.arraycopy(this.columnWeights, 0, var6.weightX, 0, this.columnWeights.length);
         }

         if (this.rowWeights != null) {
            System.arraycopy(this.rowWeights, 0, var6.weightY, 0, this.rowWeights.length);
         }

         int var17 = Integer.MAX_VALUE;

         for(int var49 = 1; var49 != Integer.MAX_VALUE; var17 = Integer.MAX_VALUE) {
            for(int var41 = 0; var41 < var10.length; ++var41) {
               Component var37 = var10[var41];
               if (var37.isVisible()) {
                  GridBagConstraints var39 = this.lookupConstraints(var37);
                  if (var39.tempWidth == var49) {
                     int var64 = var39.tempX + var39.tempWidth;
                     double var24 = var39.weightx;

                     for(int var13 = var39.tempX; var13 < var64; ++var13) {
                        var24 -= var6.weightX[var13];
                     }

                     if (var24 > (double)0.0F) {
                        double var26 = (double)0.0F;

                        for(int var50 = var39.tempX; var50 < var64; ++var50) {
                           var26 += var6.weightX[var50];
                        }

                        for(int var51 = var39.tempX; var26 > (double)0.0F && var51 < var64; ++var51) {
                           double var30 = var6.weightX[var51];
                           double var32 = var30 * var24 / var26;
                           double[] var10000 = var6.weightX;
                           var10000[var51] += var32;
                           var24 -= var32;
                           var26 -= var30;
                        }

                        double[] var88 = var6.weightX;
                        var88[var64 - 1] += var24;
                     }

                     int var16 = var39.minWidth + var39.ipadx + var39.insets.left + var39.insets.right;

                     for(int var52 = var39.tempX; var52 < var64; ++var52) {
                        var16 -= var6.minWidth[var52];
                     }

                     if (var16 > 0) {
                        double var77 = (double)0.0F;

                        for(int var53 = var39.tempX; var53 < var64; ++var53) {
                           var77 += var6.weightX[var53];
                        }

                        for(int var54 = var39.tempX; var77 > (double)0.0F && var54 < var64; ++var54) {
                           double var82 = var6.weightX[var54];
                           int var85 = (int)(var82 * (double)var16 / var77);
                           int[] var89 = var6.minWidth;
                           var89[var54] += var85;
                           var16 -= var85;
                           var77 -= var82;
                        }

                        int[] var90 = var6.minWidth;
                        var90[var64 - 1] += var16;
                     }
                  } else if (var39.tempWidth > var49 && var39.tempWidth < var17) {
                     var17 = var39.tempWidth;
                  }

                  if (var39.tempHeight != var49) {
                     if (var39.tempHeight > var49 && var39.tempHeight < var17) {
                        var17 = var39.tempHeight;
                     }
                  } else {
                     int var68 = var39.tempY + var39.tempHeight;
                     double var76 = var39.weighty;

                     for(int var55 = var39.tempY; var55 < var68; ++var55) {
                        var76 -= var6.weightY[var55];
                     }

                     if (var76 > (double)0.0F) {
                        double var78 = (double)0.0F;

                        for(int var56 = var39.tempY; var56 < var68; ++var56) {
                           var78 += var6.weightY[var56];
                        }

                        for(int var57 = var39.tempY; var78 > (double)0.0F && var57 < var68; ++var57) {
                           double var83 = var6.weightY[var57];
                           double var86 = var83 * var76 / var78;
                           double[] var91 = var6.weightY;
                           var91[var57] += var86;
                           var76 -= var86;
                           var78 -= var83;
                        }

                        double[] var92 = var6.weightY;
                        var92[var68 - 1] += var76;
                     }

                     int var69 = var39.minHeight + var39.ipady + var39.insets.top + var39.insets.bottom;

                     for(int var58 = var39.tempY; var58 < var68; ++var58) {
                        var69 -= var6.minHeight[var58];
                     }

                     if (var69 > 0) {
                        double var79 = (double)0.0F;

                        for(int var59 = var39.tempY; var59 < var68; ++var59) {
                           var79 += var6.weightY[var59];
                        }

                        for(int var60 = var39.tempY; var79 > (double)0.0F && var60 < var68; ++var60) {
                           double var84 = var6.weightY[var60];
                           int var87 = (int)(var84 * (double)var69 / var79);
                           int[] var93 = var6.minHeight;
                           var93[var60] += var87;
                           var69 -= var87;
                           var79 -= var84;
                        }

                        int[] var94 = var6.minHeight;
                        var94[var68 - 1] += var69;
                     }
                  }
               }
            }

            var49 = var17;
         }

         var3 = var6;
      } catch (Throwable var35) {
         throw var35;
      }

      return var3;
   }

   protected void AdjustForGravity(GridBagConstraints var1, Rectangle var2) {
      var2.x += var1.insets.left;
      var2.width -= var1.insets.left + var1.insets.right;
      var2.y += var1.insets.top;
      var2.height -= var1.insets.top + var1.insets.bottom;
      int var3 = 0;
      if (var1.fill != 2 && var1.fill != 1 && var2.width > var1.minWidth + var1.ipadx) {
         var3 = var2.width - (var1.minWidth + var1.ipadx);
         var2.width = var1.minWidth + var1.ipadx;
      }

      int var4 = 0;
      if (var1.fill != 3 && var1.fill != 1 && var2.height > var1.minHeight + var1.ipady) {
         var4 = var2.height - (var1.minHeight + var1.ipady);
         var2.height = var1.minHeight + var1.ipady;
      }

      switch (var1.anchor) {
         case 10:
            var2.x += var3 / 2;
            var2.y += var4 / 2;
            return;
         case 11:
            var2.x += var3 / 2;
            return;
         case 12:
            var2.x += var3;
            return;
         case 13:
            var2.x += var3;
            var2.y += var4 / 2;
            return;
         case 14:
            var2.x += var3;
            var2.y += var4;
            return;
         case 15:
            var2.x += var3 / 2;
            var2.y += var4;
            return;
         case 16:
            var2.y += var4;
            return;
         case 17:
            var2.y += var4 / 2;
            return;
         case 18:
            return;
         default:
            throw new IllegalArgumentException("illegal anchor value");
      }
   }

   protected Dimension GetMinSize(Container var1, GridBagLayoutInfo var2) {
      Dimension var3 = new Dimension();
      Insets var6 = var1.getInsets();
      int var5 = 0;

      for(int var4 = 0; var4 < var2.width; ++var4) {
         var5 += var2.minWidth[var4];
      }

      var3.width = var5 + var6.left + var6.right;
      var5 = 0;

      for(int var7 = 0; var7 < var2.height; ++var7) {
         var5 += var2.minHeight[var7];
      }

      var3.height = var5 + var6.top + var6.bottom;
      return var3;
   }

   protected void ArrangeGrid(Container var1) {
      Insets var5 = var1.getInsets();
      Component[] var6 = var1.getComponents();
      Rectangle var8 = new Rectangle();
      if (var6.length != 0 || this.columnWidths != null && this.columnWidths.length != 0 || this.rowHeights != null && this.rowHeights.length != 0) {
         GridBagLayoutInfo var14 = this.GetLayoutInfo(var1, 2);
         Dimension var7 = this.GetMinSize(var1, var14);
         if (var1.width < var7.width || var1.height < var7.height) {
            var14 = this.GetLayoutInfo(var1, 1);
            var7 = this.GetMinSize(var1, var14);
         }

         this.layoutInfo = var14;
         var8.width = var7.width;
         var8.height = var7.height;
         int var10 = var1.width - var8.width;
         if (var10 != 0) {
            double var12 = (double)0.0F;

            for(int var9 = 0; var9 < var14.width; ++var9) {
               var12 += var14.weightX[var9];
            }

            if (var12 > (double)0.0F) {
               for(int var16 = 0; var16 < var14.width; ++var16) {
                  int var15 = (int)((double)var10 * var14.weightX[var16] / var12);
                  int[] var10000 = var14.minWidth;
                  var10000[var16] += var15;
                  var8.width += var15;
                  if (var14.minWidth[var16] < 0) {
                     var8.width -= var14.minWidth[var16];
                     var14.minWidth[var16] = 0;
                  }
               }
            }

            var10 = var1.width - var8.width;
         } else {
            var10 = 0;
         }

         int var11 = var1.height - var8.height;
         if (var11 != 0) {
            double var25 = (double)0.0F;

            for(int var17 = 0; var17 < var14.height; ++var17) {
               var25 += var14.weightY[var17];
            }

            if (var25 > (double)0.0F) {
               for(int var18 = 0; var18 < var14.height; ++var18) {
                  int var26 = (int)((double)var11 * var14.weightY[var18] / var25);
                  int[] var27 = var14.minHeight;
                  var27[var18] += var26;
                  var8.height += var26;
                  if (var14.minHeight[var18] < 0) {
                     var8.height -= var14.minHeight[var18];
                     var14.minHeight[var18] = 0;
                  }
               }
            }

            var11 = var1.height - var8.height;
         } else {
            var11 = 0;
         }

         var14.startx = var10 / 2 + var5.left;
         var14.starty = var11 / 2 + var5.top;

         for(int var3 = 0; var3 < var6.length; ++var3) {
            Component var2 = var6[var3];
            if (var2.isVisible()) {
               GridBagConstraints var4 = this.lookupConstraints(var2);
               var8.x = var14.startx;

               for(int var19 = 0; var19 < var4.tempX; ++var19) {
                  var8.x += var14.minWidth[var19];
               }

               var8.y = var14.starty;

               for(int var20 = 0; var20 < var4.tempY; ++var20) {
                  var8.y += var14.minHeight[var20];
               }

               var8.width = 0;

               for(int var21 = var4.tempX; var21 < var4.tempX + var4.tempWidth; ++var21) {
                  var8.width += var14.minWidth[var21];
               }

               var8.height = 0;

               for(int var22 = var4.tempY; var22 < var4.tempY + var4.tempHeight; ++var22) {
                  var8.height += var14.minHeight[var22];
               }

               this.AdjustForGravity(var4, var8);
               if (var8.width > 0 && var8.height > 0) {
                  if (var2.x != var8.x || var2.y != var8.y || var2.width != var8.width || var2.height != var8.height) {
                     var2.setBounds(var8.x, var8.y, var8.width, var8.height);
                  }
               } else {
                  var2.setBounds(0, 0, 0, 0);
               }
            }
         }

      }
   }
}
