package java.awt;

import java.io.Serializable;

public class GridLayout implements LayoutManager, Serializable {
   int hgap;
   int vgap;
   int rows;
   int cols;

   public GridLayout() {
      this(1, 0, 0, 0);
   }

   public GridLayout(int var1, int var2) {
      this(var1, var2, 0, 0);
   }

   public GridLayout(int var1, int var2, int var3, int var4) {
      if (var1 == 0 && var2 == 0) {
         throw new IllegalArgumentException("rows and cols cannot both be zero");
      } else {
         this.rows = var1;
         this.cols = var2;
         this.hgap = var3;
         this.vgap = var4;
      }
   }

   public int getRows() {
      return this.rows;
   }

   public void setRows(int var1) {
      if (var1 == 0 && this.cols == 0) {
         throw new IllegalArgumentException("rows and cols cannot both be zero");
      } else {
         this.rows = var1;
      }
   }

   public int getColumns() {
      return this.cols;
   }

   public void setColumns(int var1) {
      if (var1 == 0 && this.rows == 0) {
         throw new IllegalArgumentException("rows and cols cannot both be zero");
      } else {
         this.cols = var1;
      }
   }

   public int getHgap() {
      return this.hgap;
   }

   public void setHgap(int var1) {
      this.hgap = var1;
   }

   public int getVgap() {
      return this.vgap;
   }

   public void setVgap(int var1) {
      this.vgap = var1;
   }

   public void addLayoutComponent(String var1, Component var2) {
   }

   public void removeLayoutComponent(Component var1) {
   }

   public Dimension preferredLayoutSize(Container var1) {
      Object var3 = ((Component)var1).getTreeLock();
      synchronized(var3){}

      Dimension var2;
      try {
         Insets var5 = var1.getInsets();
         int var6 = var1.getComponentCount();
         int var7 = this.rows;
         int var8 = this.cols;
         if (var7 > 0) {
            var8 = (var6 + var7 - 1) / var7;
         } else {
            var7 = (var6 + var8 - 1) / var8;
         }

         int var9 = 0;
         int var10 = 0;

         for(int var11 = 0; var11 < var6; ++var11) {
            Component var12 = var1.getComponent(var11);
            Dimension var13 = var12.getPreferredSize();
            if (var9 < var13.width) {
               var9 = var13.width;
            }

            if (var10 < var13.height) {
               var10 = var13.height;
            }
         }

         var2 = new Dimension(var5.left + var5.right + var8 * var9 + (var8 - 1) * this.hgap, var5.top + var5.bottom + var7 * var10 + (var7 - 1) * this.vgap);
      } catch (Throwable var15) {
         throw var15;
      }

      return var2;
   }

   public Dimension minimumLayoutSize(Container var1) {
      Object var3 = ((Component)var1).getTreeLock();
      synchronized(var3){}

      Dimension var2;
      try {
         Insets var5 = var1.getInsets();
         int var6 = var1.getComponentCount();
         int var7 = this.rows;
         int var8 = this.cols;
         if (var7 > 0) {
            var8 = (var6 + var7 - 1) / var7;
         } else {
            var7 = (var6 + var8 - 1) / var8;
         }

         int var9 = 0;
         int var10 = 0;

         for(int var11 = 0; var11 < var6; ++var11) {
            Component var12 = var1.getComponent(var11);
            Dimension var13 = var12.getMinimumSize();
            if (var9 < var13.width) {
               var9 = var13.width;
            }

            if (var10 < var13.height) {
               var10 = var13.height;
            }
         }

         var2 = new Dimension(var5.left + var5.right + var8 * var9 + (var8 - 1) * this.hgap, var5.top + var5.bottom + var7 * var10 + (var7 - 1) * this.vgap);
      } catch (Throwable var15) {
         throw var15;
      }

      return var2;
   }

   public void layoutContainer(Container var1) {
      Object var2 = ((Component)var1).getTreeLock();
      synchronized(var2){}

      try {
         Insets var4 = var1.getInsets();
         int var5 = var1.getComponentCount();
         int var6 = this.rows;
         int var7 = this.cols;
         if (var5 != 0) {
            if (var6 > 0) {
               var7 = (var5 + var6 - 1) / var6;
            } else {
               var6 = (var5 + var7 - 1) / var7;
            }

            int var8 = var1.width - (var4.left + var4.right);
            int var9 = var1.height - (var4.top + var4.bottom);
            var8 = (var8 - (var7 - 1) * this.hgap) / var7;
            var9 = (var9 - (var6 - 1) * this.vgap) / var6;
            int var10 = 0;

            for(int var11 = var4.left; var10 < var7; var11 += var8 + this.hgap) {
               int var12 = 0;

               for(int var13 = var4.top; var12 < var6; var13 += var9 + this.vgap) {
                  int var14 = var12 * var7 + var10;
                  if (var14 < var5) {
                     var1.getComponent(var14).setBounds(var11, var13, var8, var9);
                  }

                  ++var12;
               }

               ++var10;
            }

            return;
         }
      } catch (Throwable var16) {
         throw var16;
      }

   }

   public String toString() {
      return this.getClass().getName() + "[hgap=" + this.hgap + ",vgap=" + this.vgap + ",rows=" + this.rows + ",cols=" + this.cols + "]";
   }
}
